summaryrefslogtreecommitdiffstats
path: root/siplib
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-22 13:38:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-22 13:38:00 -0600
commite832e9f2ab4ef7c9649c5a43824c2c8f97d5c6df (patch)
tree1f6a56de772e0b9ad9b75253d7dc6fa98865e04e /siplib
parent71cbc66f6c877652370529d008263320a6cea74c (diff)
downloadsip4-tqt-e832e9f2ab4ef7c9649c5a43824c2c8f97d5c6df.tar.gz
sip4-tqt-e832e9f2ab4ef7c9649c5a43824c2c8f97d5c6df.zip
Fix accidental rename of strings to tqunicode
Diffstat (limited to 'siplib')
-rw-r--r--siplib/sip.h12
-rw-r--r--siplib/siplib.c40
2 files changed, 26 insertions, 26 deletions
diff --git a/siplib/sip.h b/siplib/sip.h
index 68622be..ddd3320 100644
--- a/siplib/sip.h
+++ b/siplib/sip.h
@@ -126,8 +126,8 @@ extern "C" {
* Added sip_api_transfer_break().
*
* 3.4 Added qt_find_connection() to the TQt support API.
- * Added sip_api_string_as_char(), sip_api_tqunicode_as_wchar(),
- * sip_api_tqunicode_as_wstring(), sip_api_find_class(),
+ * Added sip_api_string_as_char(), sip_api_unicode_as_wchar(),
+ * sip_api_unicode_as_wstring(), sip_api_find_class(),
* sip_api_find_named_enum() and sip_api_parse_signature().
* Added the 'A', 'w' and 'x' format characters to sip_api_parse_args(),
* sip_api_parse_result(), sip_api_build_result() and
@@ -1355,11 +1355,11 @@ typedef struct _sipAPIDef {
char (*api_string_as_utf8_char)(PyObject *obj);
const char *(*api_string_as_utf8_string)(PyObject **obj);
#if defined(HAVE_WCHAR_H)
- wchar_t (*api_tqunicode_as_wchar)(PyObject *obj);
- wchar_t *(*api_tqunicode_as_wstring)(PyObject *obj);
+ wchar_t (*api_unicode_as_wchar)(PyObject *obj);
+ wchar_t *(*api_unicode_as_wstring)(PyObject *obj);
#else
- int (*api_tqunicode_as_wchar)(PyObject *obj);
- int *(*api_tqunicode_as_wstring)(PyObject *obj);
+ int (*api_unicode_as_wchar)(PyObject *obj);
+ int *(*api_unicode_as_wstring)(PyObject *obj);
#endif
int (*api_deprecated)(const char *classname, const char *method);
void (*api_keep_reference)(PyObject *self, int key, PyObject *obj);
diff --git a/siplib/siplib.c b/siplib/siplib.c
index 9c8ad30..2bcaab4 100644
--- a/siplib/siplib.c
+++ b/siplib/siplib.c
@@ -232,11 +232,11 @@ static const char *sip_api_string_as_latin1_string(PyObject **obj);
static char sip_api_string_as_utf8_char(PyObject *obj);
static const char *sip_api_string_as_utf8_string(PyObject **obj);
#if defined(HAVE_WCHAR_H)
-static wchar_t sip_api_tqunicode_as_wchar(PyObject *obj);
-static wchar_t *sip_api_tqunicode_as_wstring(PyObject *obj);
+static wchar_t sip_api_unicode_as_wchar(PyObject *obj);
+static wchar_t *sip_api_unicode_as_wstring(PyObject *obj);
#else
-static int sip_api_tqunicode_as_wchar(PyObject *obj);
-static int *sip_api_tqunicode_as_wstring(PyObject *obj);
+static int sip_api_unicode_as_wchar(PyObject *obj);
+static int *sip_api_unicode_as_wstring(PyObject *obj);
#endif
static void sip_api_transfer_break(PyObject *self);
static int sip_api_deprecated(const char *classname, const char *method);
@@ -357,8 +357,8 @@ static const sipAPIDef sip_api = {
sip_api_string_as_latin1_string,
sip_api_string_as_utf8_char,
sip_api_string_as_utf8_string,
- sip_api_tqunicode_as_wchar,
- sip_api_tqunicode_as_wstring,
+ sip_api_unicode_as_wchar,
+ sip_api_unicode_as_wstring,
sip_api_deprecated,
sip_api_keep_reference,
sip_api_parse_kwd_args,
@@ -6302,7 +6302,7 @@ static void sip_api_no_method(PyObject *parseErr, const char *scope,
/*
* Return a string/tqunicode object extracted from a particular line of a
* docstring.
*/
static PyObject *signature_FromDocstring(const char *doc, SIP_SSIZE_T line)
@@ -6339,7 +6339,7 @@ static PyObject *signature_FromDocstring(const char *doc, SIP_SSIZE_T line)
/*
* Return a string/tqunicode object that describes the given failure.
*/
static PyObject *detail_FromFailure(PyObject *failure_obj)
{
@@ -9888,7 +9888,7 @@ static char sip_api_string_as_ascii_char(PyObject *obj)
#if PY_MAJOR_VERSION >= 3
"bytes or ASCII string of length 1 expected not '%s'",
#else
- "string or ASCII tqunicode of length 1 expected not '%s'",
+ "string or ASCII unicode of length 1 expected not '%s'",
#endif
Py_TYPE(obj)->tp_name);
@@ -9924,7 +9924,7 @@ static char sip_api_string_as_latin1_char(PyObject *obj)
#if PY_MAJOR_VERSION >= 3
"bytes or Latin-1 string of length 1 expected not '%s'",
#else
- "string or Latin-1 tqunicode of length 1 expected not '%s'",
+ "string or Latin-1 unicode of length 1 expected not '%s'",
#endif
Py_TYPE(obj)->tp_name);
@@ -9960,7 +9960,7 @@ static char sip_api_string_as_utf8_char(PyObject *obj)
#if PY_MAJOR_VERSION >= 3
"bytes or UTF-8 string of length 1 expected not '%s'",
#else
- "string or UTF-8 tqunicode of length 1 expected not '%s'",
+ "string or UTF-8 unicode of length 1 expected not '%s'",
#endif
Py_TYPE(obj)->tp_name);
@@ -10028,7 +10028,7 @@ static const char *sip_api_string_as_ascii_string(PyObject **obj)
#if PY_MAJOR_VERSION >= 3
"bytes or ASCII string expected not '%s'",
#else
- "string or ASCII tqunicode expected not '%s'",
+ "string or ASCII unicode expected not '%s'",
#endif
Py_TYPE(s)->tp_name);
@@ -10067,7 +10067,7 @@ static const char *sip_api_string_as_latin1_string(PyObject **obj)
#if PY_MAJOR_VERSION >= 3
"bytes or Latin-1 string expected not '%s'",
#else
- "string or Latin-1 tqunicode expected not '%s'",
+ "string or Latin-1 unicode expected not '%s'",
#endif
Py_TYPE(s)->tp_name);
@@ -10106,7 +10106,7 @@ static const char *sip_api_string_as_utf8_string(PyObject **obj)
#if PY_MAJOR_VERSION >= 3
"bytes or UTF-8 string expected not '%s'",
#else
- "string or UTF-8 tqunicode expected not '%s'",
+ "string or UTF-8 unicode expected not '%s'",
#endif
Py_TYPE(s)->tp_name);
@@ -10215,7 +10215,7 @@ static int parseBytes_AsString(PyObject *obj, const char **ap)
/*
* Convert a Python object to a wide character.
*/
-static wchar_t sip_api_tqunicode_as_wchar(PyObject *obj)
+static wchar_t sip_api_unicode_as_wchar(PyObject *obj)
{
wchar_t ch;
@@ -10225,7 +10225,7 @@ static wchar_t sip_api_tqunicode_as_wchar(PyObject *obj)
#if PY_MAJOR_VERSION >= 3
"string"
#else
- "tqunicode string"
+ "unicode string"
#endif
" of length 1 expected, not %s", Py_TYPE(obj)->tp_name);
@@ -10239,7 +10239,7 @@ static wchar_t sip_api_tqunicode_as_wchar(PyObject *obj)
/*
* Convert a Python object to a wide character string on the heap.
*/
-static wchar_t *sip_api_tqunicode_as_wstring(PyObject *obj)
+static wchar_t *sip_api_unicode_as_wstring(PyObject *obj)
{
wchar_t *p;
@@ -10249,7 +10249,7 @@ static wchar_t *sip_api_tqunicode_as_wstring(PyObject *obj)
#if PY_MAJOR_VERSION >= 3
"string"
#else
- "tqunicode string"
+ "unicode string"
#endif
" expected, not %s", Py_TYPE(obj)->tp_name);
@@ -10437,7 +10437,7 @@ static int convertToWCharString(PyObject *obj, wchar_t **ap)
/*
* Convert a Python object to a wide character.
*/
-static int sip_api_tqunicode_as_wchar(PyObject *obj)
+static int sip_api_unicode_as_wchar(PyObject *obj)
{
raiseNoWChar();
@@ -10448,7 +10448,7 @@ static int sip_api_tqunicode_as_wchar(PyObject *obj)
/*
* Convert a Python object to a wide character.
*/
-static int *sip_api_tqunicode_as_wstring(PyObject *obj)
+static int *sip_api_unicode_as_wstring(PyObject *obj)
{
raiseNoWChar();
@@ -6302,7 +6302,7 @@ static void sip_api_no_method(PyObject *parseErr, const char *scope,
/*
- * Return a string/tqunicode object extracted from a particular line of a
+ * Return a string/unicode object extracted from a particular line of a
* docstring.
*/
@@ -6339,7 +6339,7 @@ static PyObject *signature_FromDocstring(const char *doc, SIP_SSIZE_T line)
/*
- * Return a string/tqunicode object that describes the given failure.
+ * Return a string/unicode object that describes the given failure.
*/
static PyObject *detail_FromFailure(PyObject *failure_obj)